@@ -91,16 +91,40 @@ guess_has_R4.1_features <- function() {
         return (FALSE)
 
     device <- names(grDevices::dev.cur())
-    if (device %in% c("bmp", "cairo_pdf", "cairo_ps", "jpeg", "pdf", "png",
-                      "svg", "tiff", "X11cairo")) {
+    if (device %in% c("cairo_pdf", "cairo_ps", "pdf", "svg", "X11cairo")) {
         TRUE
-    } else if (device == "agg_png") {
+    } else if (device %in% c("bmp", "jpeg", "png", "tiff")) {
+        switch(.Platform$OS.type,
+               windows = FALSE,
+               unix = isTRUE(capabilities("cairo")))
+    } else if (device %in% c("agg_jpeg", "agg_ppm", "agg_png", "agg_tiff")) {
         packageVersion("ragg") >= '1.2.0'
+    } else if (device == "devSVG") {
+        # {vdiffr}'s embedded {svglite} graphics device is also called "devSGV"
+        # but doesn't support R 4.1 features (yet)
+        if (likely_called_by_vdiffr()) {
+            FALSE
+        } else {
+            packageVersion("svglite") >= '2.1.0'
+        }
     } else {
         FALSE
     }
 }
 
+# `vdiffr::write_svg()` is the function that calls the embedded {svglite}
+# but when `vdiffr::expect_doppelganger()` calls it its call is "writer"
+likely_called_by_vdiffr <- function() {
+    n <- sys.nframe()
+    while(n > 0) {
+        call <- as.character(sys.call(n))
+        if (grepl("write_svg$|expect_doppelganger$", call[1]))
+            return(TRUE)
+        n <- n - 1L
+    }
+    FALSE
+}
+
 get_R4.1_params <- function(l) {
     # R 4.1 features
     default <- guess_has_R4.1_features()
